@@ -1,7 +1,7 @@
 /*
  * This file is part of budgie-desktop
  *
- * Copyright © 2016 Ikey Doherty <ikey@solus-project.com>
+ * Copyright © 2016-2019 Budgie Desktop Developers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -166,7 +166,8 @@ remove_provider:
         self->css_provider = css_provider;
 }
 
-static void budgie_theme_manager_theme_changed(BudgieThemeManager *self, GParamSpec *prop,
+static void budgie_theme_manager_theme_changed(BudgieThemeManager *self,
+                                               __attribute__((unused)) GParamSpec *prop,
                                                GtkSettings *settings)
 {
         gchar *theme_name = NULL;
@@ -176,9 +177,9 @@ static void budgie_theme_manager_theme_changed(BudgieThemeManager *self, GParamS
         if (self->builtin_enabled) {
                 g_object_get(settings, "gtk-theme-name", &theme_name, NULL);
                 if (theme_name && g_str_equal(theme_name, "HighContrast")) {
-                        theme_css = "theme_hc.css";
+                        theme_css = "theme_hc";
                 } else {
-                        theme_css = "theme.css";
+                        theme_css = "theme";
                 }
                 g_free(theme_name);
         }
